@@ -1,15 +1,15 @@
-import nautilus
 import gobject
+from gi.repository import Nautilus
 
-class UpdateFileInfoAsync(nautilus.InfoProvider):
+class UpdateFileInfoAsync(gobject.GObject, Nautilus.InfoProvider):
     def __init__(self):
         pass
     
     def update_file_info_full(self, provider, handle, closure, file):
         print "update_file_info_full"
         gobject.timeout_add_seconds(3, self.update_cb, provider, handle, closure)
-        return nautilus.OPERATION_IN_PROGRESS
+        return Nautilus.OperationResult.IN_PROGRESS
         
     def update_cb(self, provider, handle, closure):
         print "update_cb"
-        self.update_complete_invoke(provider, handle, closure, result=nautilus.OPERATION_FAILED)
+        Nautilus.info_provider_update_complete_invoke(closure, provider, handle, Nautilus.OperationResult.FAILED)
